S4toS3: Converts an S4 class SBML object created by rsbml into an S3 object of class SBMLR
Description
This function provides a path from rsbml to SBMLR. The latter, being S3, is less cluttered
with empty fields/slots than the former. The advantage of the S4 object is that it comes from
more robust SBML reading: rsbml uses libsbml to parse SBML, SBMLR uses the R package XML.
Usage
S4toS3(dom)
Arguments
dom
An S4 DOM object of class SBML produced by rsbml.
Value
Details
Carried over are compartments, species, global parameters, rules and reactions.